Improve this doc

Our application is now complete. Feel free to experiment with the code further, and jump back to previous steps using the `git checkout` command.

For more details and examples of the Angular concepts we touched on in this tutorial, see the Developer Guide.

When you are ready to start developing a project using Angular, we recommend that you bootstrap your development with the angular-seed project.

We hope this tutorial was useful to you and that you learned enough about Angular to make you want to learn more. We especially hope you are inspired to go out and develop Angular web apps of your own, and that you might be interested in contributing to Angular.

If you have questions or feedback or just want to say "hi", please post a message at (https://groups.google.com/forum/#!forum/angular).